]> git.cameronkatri.com Git - mandoc.git/blobdiff - mandoc.h
Fix formatting of empty .Bl -inset item heads.
[mandoc.git] / mandoc.h
index 6056ab5a63a042c513200562e1621485785c7294..1a0256eb3d88c145d19ebf2a4320bd7da879ad4b 100644 (file)
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,4 +1,4 @@
-/*     $Id: mandoc.h,v 1.124 2014/06/30 23:45:07 schwarze Exp $ */
+/*     $Id: mandoc.h,v 1.132 2014/07/03 23:24:56 schwarze Exp $ */
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
@@ -49,46 +49,50 @@ enum        mandocerr {
        MANDOCERR_WARNING, /* ===== start of warnings ===== */
 
        /* related to the prologue */
        MANDOCERR_WARNING, /* ===== start of warnings ===== */
 
        /* related to the prologue */
-       MANDOCERR_TH_MISSING, /* no TH macro in document */
-       MANDOCERR_TITLE_CASE, /* document title should be all caps */
-       MANDOCERR_MSEC_BAD, /* unknown manual section */
-       MANDOCERR_ARCH_BAD, /* unknown manual volume or arch */
-       MANDOCERR_DATE_MISSING, /* date missing, using today's date */
-       MANDOCERR_DATE_BAD, /* cannot parse date, using it verbatim */
-       MANDOCERR_PROLOG_ORDER, /* prologue macros out of order */
-       MANDOCERR_PROLOG_REP, /* duplicate prologue macro */
-       MANDOCERR_PROLOG_BAD, /* macro not allowed in prologue: macro */
-       MANDOCERR_PROLOG_ONLY, /* macro not allowed in body: macro */
+       MANDOCERR_TH_MISSING, /* missing .TH macro, using "unknown 1" */
+       MANDOCERR_TITLE_CASE, /* lower case character in document title */
+       MANDOCERR_MSEC_BAD, /* unknown manual section: section */
+       MANDOCERR_ARCH_BAD, /* unknown manual volume or arch: volume */
+       MANDOCERR_DATE_MISSING, /* missing date, using today's date */
+       MANDOCERR_DATE_BAD, /* cannot parse date, using it verbatim: date */
+       MANDOCERR_PROLOG_ORDER, /* prologue macros out of order: macro */
+       MANDOCERR_PROLOG_REP, /* duplicate prologue macro: macro */
+       MANDOCERR_PROLOG_BAD, /* incomplete prologue, terminated by: macro */
+       MANDOCERR_PROLOG_ONLY, /* skipping prologue macro in body: macro */
 
        /* related to document structure */
        MANDOCERR_SO, /* .so is fragile, better use ln(1): .so path */
        MANDOCERR_DOC_EMPTY, /* no document body */
 
        /* related to document structure */
        MANDOCERR_SO, /* .so is fragile, better use ln(1): .so path */
        MANDOCERR_DOC_EMPTY, /* no document body */
-       MANDOCERR_SEC_BEFORE, /* content before the first section header */
-       MANDOCERR_NAMESECFIRST, /* NAME section must come first */
-       MANDOCERR_BADNAMESEC, /* bad NAME section contents */
-       MANDOCERR_SECOOO, /* sections out of conventional order */
-       MANDOCERR_SECREP, /* duplicate section name */
-       MANDOCERR_SECMSEC, /* section header suited to sections ... */
+       MANDOCERR_SEC_BEFORE, /* content before first section header: macro */
+       MANDOCERR_NAMESEC_FIRST, /* first section is not "NAME": title */
+       MANDOCERR_NAMESEC_BAD, /* bad NAME section contents: macro */
+       MANDOCERR_SEC_ORDER, /* sections out of conventional order: title */
+       MANDOCERR_SEC_REP, /* duplicate section title: title */
+       MANDOCERR_SEC_MSEC, /* unexpected section: title for ... only */
 
        /* related to macros and nesting */
 
        /* related to macros and nesting */
-       MANDOCERR_MACROOBS, /* skipping obsolete macro */
-       MANDOCERR_IGNPAR, /* skipping paragraph macro */
-       MANDOCERR_MOVEPAR, /* moving paragraph macro out of list */
-       MANDOCERR_IGNNS, /* skipping no-space macro */
-       MANDOCERR_SCOPENEST, /* blocks badly nested */
-       MANDOCERR_CHILD, /* child violates parent syntax */
-       MANDOCERR_NESTEDDISP, /* nested displays are not portable */
-       MANDOCERR_SCOPEREP, /* already in literal mode */
-       MANDOCERR_LINESCOPE, /* line scope broken */
-
-       /* related to missing macro arguments */
-       MANDOCERR_MACROEMPTY, /* skipping empty macro */
+       MANDOCERR_MACRO_OBS, /* obsolete macro: macro */
+       MANDOCERR_PAR_SKIP, /* skipping paragraph macro: macro ... */
+       MANDOCERR_PAR_MOVE, /* moving paragraph macro out of list: macro */
+       MANDOCERR_NS_SKIP, /* skipping no-space macro */
+       MANDOCERR_BLOCK_NEST, /* blocks badly nested: macro ... */
+       MANDOCERR_BD_NEST, /* nested displays are not portable: macro ... */
+       MANDOCERR_BL_MOVE, /* moving content out of list: macro */
+       MANDOCERR_VT_CHILD, /* .Vt block has child macro: macro */
+       MANDOCERR_FI_SKIP, /* fill mode already enabled, skipping .fi */
+       MANDOCERR_NF_SKIP, /* fill mode already disabled, skipping .nf */
+       MANDOCERR_LINESCOPE, /* line scope broken: macro breaks macro */
+
+       /* related to missing arguments */
+       MANDOCERR_REQ_EMPTY, /* skipping empty request: request */
+       MANDOCERR_COND_EMPTY, /* conditional request controls empty scope */
+       MANDOCERR_MACRO_EMPTY, /* skipping empty macro: macro */
        MANDOCERR_ARGCWARN, /* argument count wrong */
        MANDOCERR_DISPTYPE, /* missing display type */
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
        MANDOCERR_ARGCWARN, /* argument count wrong */
        MANDOCERR_DISPTYPE, /* missing display type */
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
+       MANDOCERR_IT_NOHEAD, /* missing head in list item: type */
        MANDOCERR_FONTTYPE, /* missing font type */
        MANDOCERR_FONTTYPE, /* missing font type */
-       MANDOCERR_WNOSCOPE, /* skipping end of block that is not open */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
@@ -132,17 +136,17 @@ enum      mandocerr {
        MANDOCERR_BADCHAR, /* skipping bad character */
        MANDOCERR_NAMESC, /* escaped character not allowed in a name */
        MANDOCERR_NONAME, /* manual name not yet set */
        MANDOCERR_BADCHAR, /* skipping bad character */
        MANDOCERR_NAMESC, /* escaped character not allowed in a name */
        MANDOCERR_NONAME, /* manual name not yet set */
-       MANDOCERR_NOTEXT, /* skipping text before the first section header */
+       MANDOCERR_NOTEXT, /* skipping text before first section header */
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
+       MANDOCERR_RS_SKIP, /* skipping invalid content in .Rs block: macro */
        MANDOCERR_STRAYTA, /* skipping column outside column list */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */
        MANDOCERR_SCOPEEXIT, /* scope open on exit */
        MANDOCERR_UNAME, /* uname(3) system call failed */
        /* FIXME: merge following with MANDOCERR_ARGCOUNT */
        MANDOCERR_STRAYTA, /* skipping column outside column list */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */
        MANDOCERR_SCOPEEXIT, /* scope open on exit */
        MANDOCERR_UNAME, /* uname(3) system call failed */
        /* FIXME: merge following with MANDOCERR_ARGCOUNT */
-       MANDOCERR_NOARGS, /* macro requires line argument(s) */
        MANDOCERR_NOBODY, /* macro requires body argument(s) */
        MANDOCERR_NOARGV, /* macro requires argument(s) */
        MANDOCERR_NUMERIC, /* request requires a numeric argument */
        MANDOCERR_NOBODY, /* macro requires body argument(s) */
        MANDOCERR_NOARGV, /* macro requires argument(s) */
        MANDOCERR_NUMERIC, /* request requires a numeric argument */